# -*- coding: utf-8 -*-
"""
SOLEIL synchrotron parameters script.

@author: Alexis Gamelin
@date: 14/01/2020
"""

import numpy as np
from tracking.synchrotron import Synchrotron
from tracking.optics import Optics
from tracking.particles import Electron, Beam

def soleil(mode = 'Uniform'):
    """
    
    """
    
    h = 416
    L = 3.540969742590899e+02
    E0 = 2.75e9
    particle = Electron()
    ac = 1.47e-4
    U0 = 0.310e6
    tau = np.array([6.56e-3, 6.56e-3, 3.27e-3])
    tune = np.array([18.15687, 10.22824, 0.00502])
    emit = np.array([4.5e-9, 4.5e-9*0.01])
    sigma_0 = 8e-12
    sigma_delta = 8.6e-4
    chro = [2,3]
    
    # mean values
    beta = np.array([3, 1.3])
    alpha = np.array([0, 0])
    dispersion = np.array([0, 0, 0, 0])
    optics = Optics(local_beta=beta, local_alpha=alpha, 
                      local_dispersion=dispersion)
    
    ring = Synchrotron(h, optics, particle, L=L, E0=E0, ac=ac, U0=U0, tau=tau,
                       emit=emit, tune=tune, sigma_delta=sigma_delta, 
                       sigma_0=sigma_0, chro=chro)
    
    return ring

def v0313():
    """
    
    """
    
    h = 416
    particle = Electron()
    tau = np.array([7.3e-3, 13.1e-3, 11.7e-3])
    emit = np.array([53.47e-12, 53.47e-12])
    sigma_0 = 9.2e-12
    sigma_delta = 9e-4
    
    lattice_file = "SOLEIL_U_74BA_HOA_SYM02_V0313_cleaned.mat"
    optics = Optics(lattice_file=lattice_file)
    
    ring = Synchrotron(h, optics, particle, tau=tau, emit=emit, 
                       sigma_0=sigma_0, sigma_delta=sigma_delta)
        
    return ring